
Canonicalised user input
-------

**Description:**

Whenever user-input is partially validated there is a high probability that the application 
misses a malicious input which could execute into a successful attack on your application.


**Solution:**

All userinput should be validated whenever the user-input string is complete and is being 
processed by your application.
